This data set is bibliographic information retrieved with ArticleSearch funtion from this package, it contains the main information of articles related with Knowledge Domain Visualization field.
KDVizDataA dataframe containing the information of Keywords and URLs from 757 articles related to the keywords knowledge domain visualization, document clustering, co-words and co-citation.